Index: uspace/lib/libc/generic/async.c
===================================================================
--- uspace/lib/libc/generic/async.c	(revision d40a8ffa6b8ec244d5fe541f890ee182cc6727a9)
+++ uspace/lib/libc/generic/async.c	(revision b61d47d14bdea0c512d1a9a0ce603ef37ac239bc)
@@ -539,5 +539,5 @@
 	case IPC_M_CONNECT_ME_TO:
 		/* Open new connection with fibril etc. */
-		async_new_connection(IPC_GET_ARG3(*call), callid, call,
+		async_new_connection(IPC_GET_ARG5(*call), callid, call,
 		    client_connection);
 		return;
Index: uspace/lib/libc/generic/io/stream.c
===================================================================
--- uspace/lib/libc/generic/io/stream.c	(revision d40a8ffa6b8ec244d5fe541f890ee182cc6727a9)
+++ uspace/lib/libc/generic/io/stream.c	(revision b61d47d14bdea0c512d1a9a0ce603ef37ac239bc)
@@ -97,5 +97,5 @@
 	if (console_phone < 0) {
 		while ((console_phone = ipc_connect_me_to(PHONE_NS,
-		    SERVICE_CONSOLE, 0)) < 0) {
+		    SERVICE_CONSOLE, 0, 0)) < 0) {
 			usleep(10000);
 		}
@@ -116,5 +116,5 @@
 	if (console_phone < 0) {
 		while ((console_phone = ipc_connect_me_to(PHONE_NS,
-		    SERVICE_CONSOLE, 0)) < 0) {
+		    SERVICE_CONSOLE, 0, 0)) < 0) {
 			usleep(10000);
 		}
Index: uspace/lib/libc/include/ipc/ipc.h
===================================================================
--- uspace/lib/libc/include/ipc/ipc.h	(revision d40a8ffa6b8ec244d5fe541f890ee182cc6727a9)
+++ uspace/lib/libc/include/ipc/ipc.h	(revision b61d47d14bdea0c512d1a9a0ce603ef37ac239bc)
@@ -254,10 +254,10 @@
 
 extern int ipc_connect_to_me(int phoneid, int arg1, int arg2, ipcarg_t *phone);
-extern int ipc_connect_me_to(int phoneid, int arg1, int arg2);
+extern int ipc_connect_me_to(int phoneid, int arg1, int arg2, int arg3);
 extern int ipc_hangup(int phoneid);
 extern int ipc_register_irq(int inr, int devno, int method, irq_code_t *code);
 extern int ipc_unregister_irq(int inr, int devno);
 extern int ipc_forward_fast(ipc_callid_t callid, int phoneid, int method,
-    ipcarg_t arg1, int mode);
+    ipcarg_t arg1, ipcarg_t arg2, int mode);
 extern int ipc_data_send(int phoneid, void *src, size_t size);
 extern int ipc_data_receive(ipc_callid_t *callid, void **dst, size_t *size);

Index: uspace/lib/libc/generic/ipc.c
===================================================================
--- uspace/lib/libc/generic/ipc.c	(revision d40a8ffa6b8ec244d5fe541f890ee182cc6727a9)
+++ uspace/lib/libc/generic/ipc.c	(revision b61d47d14bdea0c512d1a9a0ce603ef37ac239bc)
@@ -588,14 +588,15 @@
  * @param arg1		User defined argument.
  * @param arg2		User defined argument.
+ * @param arg3		User defined argument.
  *
  * @return		New phone handle on success or a negative error code.
  */
-int ipc_connect_me_to(int phoneid, int arg1, int arg2)
+int ipc_connect_me_to(int phoneid, int arg1, int arg2, int arg3)
 {
 	ipcarg_t newphid;
 	int res;
 
-	res = ipc_call_sync_2_3(phoneid, IPC_M_CONNECT_ME_TO, arg1, arg2, NULL,
-	    NULL, &newphid);
+	res = ipc_call_sync_3_5(phoneid, IPC_M_CONNECT_ME_TO, arg1, arg2, arg3, 
+		NULL, NULL, NULL, NULL, &newphid);
 	if (res)
 		return res;
@@ -647,4 +648,5 @@
  * @param method	New method for the forwarded call.
  * @param arg1		New value of the first argument for the forwarded call.
+ * @param arg2		New value of the second argument for the forwarded call.
  * @param mode		Flags specifying mode of the forward operation.
  *
@@ -652,13 +654,13 @@
  *
  * For non-system methods, the old method and arg1 are rewritten by the new
  * values. For system methods, the new method and arg1 are written to the old
  * arg1 and arg2, respectivelly. Calls with immutable methods are forwarded
  * verbatim.
  */
 int ipc_forward_fast(ipc_callid_t callid, int phoneid, int method,
-    ipcarg_t arg1, int mode)
-{
-	return __SYSCALL5(SYS_IPC_FORWARD_FAST, callid, phoneid, method, arg1,
-	    mode);
+    ipcarg_t arg1, ipcarg_t arg2, int mode)
+{
+	return __SYSCALL6(SYS_IPC_FORWARD_FAST, callid, phoneid, method, arg1, 
+		arg2, mode);
 }
 
@@ -652,13 +654,13 @@
  *
  * For non-system methods, the old method and arg1 are rewritten by the new
- * values. For system methods, the new method and arg1 are written to the old
- * arg1 and arg2, respectivelly. Calls with immutable methods are forwarded
- * verbatim.
+ * values. For system methods, the new method, arg1 and arg2 are written 
+ * to the old arg1, arg2 and arg3, respectivelly. Calls with immutable 
+ * methods are forwarded verbatim.
  */
 int ipc_forward_fast(ipc_callid_t callid, int phoneid, int method,